"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.scrollWithMarginTop = void 0;
/**
 * Scroll to an element taking into account its "scroll-margin-top"/"scroll-snap-margin-top".
 * This will help with Safari < 14.1 / Safari iOS <= 1.4, which doesn't support "scroll-margin-top".
 */

var scrollWithMarginTop = function scrollWithMarginTop(element) {
  var offset = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  if (!element) return;
  var rect = element.getBoundingClientRect();
  var top = rect.top + window.pageYOffset;
  var style = window.getComputedStyle(element);
  var scrollMarginTop = parseInt(style.getPropertyValue('scroll-margin-top')) || parseInt(style.getPropertyValue('scroll-snap-margin-top')) || 0;
  var newPosition = top - scrollMarginTop + offset;
  window.scrollTo({
    top: newPosition,
    left: 0,
    behavior: 'smooth'
  });
};

exports.scrollWithMarginTop = scrollWithMarginTop;